# RaspberryPi 0 et E-link

![tag](RaspberryPi)
![category](Python)

J'ai fait l'acquisition d'un raspberrypi 0 et d'un écran [E-link](https://www.kubii.com/fr/ecrans-supports/2461-ecran-213-e-ink-250x122-kubii-3272496014176.html?mot_tcid=e5cf73da-f0ef-4b24-b35b-a6e1dc890720)

## Installation Raspberry

Le raspberrypi 0 est le plus petit de la gamme ... il n'a pas de haute performance maus pour faire un module connectable et autonome il convient très bien.

Pour son installation rien de plus simple

- téléchargement de l'image **lite** sur le site https://www.raspberrypi.com/software/operating-systems/
- création d'une carte via l'outil https://etcher.balena.io/
- pour activer le ssh au démarrage: il suffit de créer un fichier vide, appelé ssh, dans la partition « Boot » de la carte SD.
- création d'un utilisateur par defaut: il faut donc indiquer un nom d’utilisateur et un mot de passe dans un fichier userconf de la partition « Boot ». le fichier contient uniqument username:encrypted-password ... pour obtenir un password crypté

```
echo 'mypassword' | openssl passwd -6 -stdin
```

- pour activer le wifi au démarrage: il faut créer un fichier wpa_supplicant.conf dans la partition « Boot » de la carte SD

```
ctrl_interface=DIR=/var/run/wpa_supplicant GROUP=netdev
update_config=1
country=FR

network={
     ssid="your_ssid"
     psk="your_password"
     key_mgmt=WPA-PSK
}
```

ou pour un wifi sans sécurité

```
ctrl_interface=DIR=/var/run/wpa_supplicant GROUP=netdev
update_config=1
country=FR

network={
     ssid="your_ssid"
     key_mgmt=NONE
}
```

A priori il y a un soucis de gestion ipv6, si avec **ifconfig** vous voyez une adresse ipv6

- Éditer le fichier /etc/sysctl.conf et ajouter ces lignes à la fin du fichier

```
net.ipv6.conf.all.disable_ipv6=1
net.ipv6.conf.default.disable_ipv6=1
net.ipv6.conf.lo.disable_ipv6=1
net.ipv6.conf.eth0.disable_ipv6 = 1
```

- Éditer le fichier /etc/rc.local et ajouter cette ligne à la fin du fichier (mais avant exit 0)

```
service procps reload
```

- Redémarrer le rpi


j'ai rencontré un soucis avec le wifi qui se déconnectait souvent sans raison ... en faite il y a un mode de gestion de l'énergie sur la carte wifi si elle n'est pas solicité.

Pour changer ce fonctionnement j'ai rajouter dans /etc/rc.local (avant le exit)

```
/sbin/iwconfig wlan0 power off
```

## Utilisation du E-link

il faut tous d'abord installer les pré requis et récupérer le module python qui va bien

```
apt-get update 
apt-get install python3-pip vim git

git clone https://github.com/waveshare/e-Paper.git


pip install setuptools
pip install spidev
pip install gpiozero
pip install pillow
```

puis activer sur le raspberry le module **SPI**

```
Run sudo raspi-config
Select Interfacing Options
Arrow down to SPI
Select yes when it asks you to enable SPI
```

dans le cas d'un ecran **tactile**  il faudra aussi activer sur le raspberry le module **I2C**

```
Run sudo raspi-config
Select Interfacing Options
Arrow down to I2C
Select yes when it asks you to enable I2C
```

et enfin dans  placer le fichier test.py et le lancer

```
from PIL import Image, ImageDraw, ImageFont
import os
import socket
import sys
import warnings

SRCDIR = "/root/e-Paper-master/RaspberryPi_JetsonNano/python"

sys.path.append(os.path.join(SRCDIR, "lib"))

# Suppress GPIO library warning:
with warnings.catch_warnings():
    warnings.simplefilter("ignore")
    from waveshare_epd import epd2in13_V4

def get_ip_address():
    s = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
    s.connect(('8.8.8.8', 80))
    local_ip_address = s.getsockname()[0]
    s.close()
    return local_ip_address

picdir = os.path.join(SRCDIR, 'pic')
font16 = ImageFont.truetype(os.path.join(picdir, 'Font.ttc'), 20)
font24 = ImageFont.truetype(os.path.join(picdir, 'Font.ttc'), 24)
epd = epd2in13_V4.EPD()
epd.init()
image = Image.new('1', (epd.height, epd.width), 127)
draw = ImageDraw.Draw(image)
draw.text((10, 68), 'ip address', font = font16, fill = 0)
draw.text((10, 90), f'{get_ip_address()}', font = font24, fill = 0)
epd.display(epd.getbuffer(image))
epd.sleep()
print("OK")
```

## passer un programme en mode service

on peut faire en sorte que le programme python ce lance en tant que service au demarrage du raspberry

```
cd /lib/systemd/system/
vi hello.service
```
On définit le service ainsi

```
[Unit]
Description=Hello World
After=multi-user.target

[Service]
Type=simple
ExecStart=/usr/bin/python /home/pi/hello_world.py
Restart=on-abort

[Install]
WantedBy=multi-user.target
```

On peut maintenant activer le service

```
chmod 644 /lib/systemd/system/hello.service
chmod +x /home/pi/hello_world.py
systemctl daemon-reload
systemctl enable hello.service
systemctl start hello.service
```

on aura accès aux commandes classiques des srvices

```
systemctl status hello.service
systemctl start hello.service
systemctl stop hello.service
journalctl -f -u hello.service
```